#
# Use this to send i18n email messages
#
# Usage:
#
#  SendEmail::sendEmail($to, $from, $subject, $body, $cc, $bcc);
#
# The $subject and $body args should be i18n strings.
# $cc and $bcc are optional.
#

package SendEmail;

use lib '/usr/sausalito/perl';
use CCE;
use I18n;
use Jcode;
use I18nMail;

my $mailBin = "/usr/sbin/sendmail -t -i";

sub getLocale
{
  my $whichUser = shift;
  my $locale;

  my $cce = new CCE;
  $cce->connectuds();
  my (@oids) = $cce->find('User', {'name' => $whichUser});
  if (@oids) {
	my ($ok, $user) = $cce->get($oids[0]);
	if ($ok) {
		$locale = $user->{'localePreference'} || "";
	}
  }

  if (!$locale || $locale eq 'browser') {
  	$locale = I18n::i18n_getSystemLocale($cce);
  }
  $cce->bye("SUCCESS");

  return $locale ? $locale : "en";
}

sub sendEmail
{
  my ($to, $from, $subject, $body, $cc, $bcc, $locale) = @_;

  if (! defined($locale)) {
      $locale = getLocale((split/,/,$to)[0]);
  }
  return 1 if (! defined ($locale));

  my $i18n = new I18n;
  $i18n->setLocale($locale);

  my $mail=new I18nMail($locale);

  if($subject) {
    $subject = $i18n->interpolate($subject);
  }
  
  if($body) {
    $body = $i18n->interpolate($body);
  }

  $mail->setLang($locale);
  $mail->setSubject($subject) || die "1";
  $mail->addTo(split/,/,$to) || die "2";
  ($mail->addCc(split/,/,$cc) || die "3") if defined $cc && $cc ne "";
  ($mail->addBcc(split/,/,$bcc) || die "4") if defined $bcc && $bcc ne "";
  $mail->setBody($body) || die "5";
  $mail->setFrom($from) || die "6";
  
#  print $mail->toText();

  if (open(MAIL, "| $mailBin")) {
      print MAIL $mail->toText();
      close(MAIL);
      return $?;
  }
  return -1;
}

1;
